<?php
// $Id: CacheEngine.php,v 1.1.2.1 2009/07/20 09:17:38 doq Exp $
//new Redis();
/**
 * Base cache engine class.
 */
class CacheEngine {
  /**
   *
   */
  var $settings = array();

  /**
   *
   */
  var $content = array();

  /**
   *
   */
  var $prefix = '';

  /**
   *
   */
  var $name = NULL;

  /**
   * Lookup key name.
   */
  var $lookup = '';
  
  /**
   * Lock key name.
   */
  var $lock = '';

  var $fast_cache = TRUE;

  /**
   * If TRUE then also cache fetched values in PHP static variable. Might
   * increase performance when enabled for cache_path_src, cache_path_dst
   * cache bins.
   */
  var $static = FALSE;

  function __construct($settings) {
    $this->settings = $settings;

    // Add defaults.
    $this->settings += array(
      'prefix' => '',
      'static' => FALSE,
      'fast_cache' => TRUE,
    );

    $this->prefix = $this->settings['prefix'];
    $this->name = $this->settings['bin'];
    $this->static = $this->settings['static'];
    $this->fast_cache = $this->settings['fast_cache'];

    // Setup prefixed lookup and lock table names for shared storage.
    $prefix = strlen($this->prefix) > 0 ? $this->prefix .',' : '';
    $this->lookup = $prefix .'lookup,'. $this->name;
    $this->lock = $prefix .'lock,'. $this->name;
  }

  function get($key) {
    if ($this->static && isset($this->content[$key])) {
      return $this->content[$key];
    }
  }

  function set($key, $value) {
    if ($this->static) {
      $this->content[$key] = $value;
    }
  }

  function delete($key) {
    if ($this->static) {
      unset($this->content[$key]);
    }
  }

  function flush() {
    if ($this->static) {
      $this->content = array();
    }
  }

  /**
   * Get the full key of the item.
   *
   * @param string $key
   *   The key to set.
   * @return string
   *   Returns the full key of the cache item.
   */
  function key($key) {
    $prefix = strlen($this->prefix) > 0 ? $this->prefix .',' : '';
    return urlencode($prefix . $this->name .','. $key);
  }

}
